#include "header.h"

status_t MECC_GetSingleErrorInfo(MECC_Type *base, mecc_single_error_info_t *info, uint8_t banknumber)
{
    assert(info != NULL);
    status_t status     = kStatus_Success;
    uint8_t tempPosLow  = 0U;
    uint8_t tempPosHigh = 0U;
    uint32_t counter    = 0U;

    switch (banknumber)
    {
        case kMECC_OcramBank0:
            info->singleErrorEccCode =
                (uint8_t)((base->SINGLE_ERR_ADDR_ECC0 & MECC_SINGLE_ERR_ADDR_ECC0_SINGLE_ERR_ECC_MASK) >>
                          MECC_SINGLE_ERR_ADDR_ECC0_SINGLE_ERR_ECC_SHIFT);
            info->singleErrorAddress = (base->SINGLE_ERR_ADDR_ECC0 & MECC_SINGLE_ERR_ADDR_ECC0_SINGLE_ERR_ADDR_MASK) >>
                                       MECC_SINGLE_ERR_ADDR_ECC0_SINGLE_ERR_ADDR_SHIFT;
            info->singleErrorDataLow  = base->SINGLE_ERR_DATA_LOW0;
            info->singleErrorDataHigh = base->SINGLE_ERR_DATA_HIGH0;
            tempPosLow                = (uint8_t)base->SINGLE_ERR_POS_LOW0;
            tempPosHigh               = (uint8_t)base->SINGLE_ERR_POS_HIGH0;
            break;

        case kMECC_OcramBank1:
            info->singleErrorEccCode =
                (uint8_t)((base->SINGLE_ERR_ADDR_ECC1 & MECC_SINGLE_ERR_ADDR_ECC1_SINGLE_ERR_ECC_MASK) >>
                          MECC_SINGLE_ERR_ADDR_ECC1_SINGLE_ERR_ECC_SHIFT);
            info->singleErrorAddress = (base->SINGLE_ERR_ADDR_ECC1 & MECC_SINGLE_ERR_ADDR_ECC1_SINGLE_ERR_ADDR_MASK) >>
                                       MECC_SINGLE_ERR_ADDR_ECC1_SINGLE_ERR_ADDR_SHIFT;
            info->singleErrorDataLow  = base->SINGLE_ERR_DATA_LOW1;
            info->singleErrorDataHigh = base->SINGLE_ERR_DATA_HIGH1;
            tempPosLow                = (uint8_t)base->SINGLE_ERR_POS_LOW1;
            tempPosHigh               = (uint8_t)base->SINGLE_ERR_POS_HIGH1;
            break;

        case kMECC_OcramBank2:
            info->singleErrorEccCode =
                (uint8_t)((base->SINGLE_ERR_ADDR_ECC2 & MECC_SINGLE_ERR_ADDR_ECC2_SINGLE_ERR_ECC_MASK) >>
                          MECC_SINGLE_ERR_ADDR_ECC2_SINGLE_ERR_ECC_SHIFT);
            info->singleErrorAddress = (base->SINGLE_ERR_ADDR_ECC2 & MECC_SINGLE_ERR_ADDR_ECC2_SINGLE_ERR_ADDR_MASK) >>
                                       MECC_SINGLE_ERR_ADDR_ECC2_SINGLE_ERR_ADDR_SHIFT;
            info->singleErrorDataLow  = base->SINGLE_ERR_DATA_LOW2;
            info->singleErrorDataHigh = base->SINGLE_ERR_DATA_HIGH2;
            tempPosLow                = (uint8_t)base->SINGLE_ERR_POS_LOW2;
            tempPosHigh               = (uint8_t)base->SINGLE_ERR_POS_HIGH2;
            break;

        case kMECC_OcramBank3:
            info->singleErrorEccCode =
                (uint8_t)((base->SINGLE_ERR_ADDR_ECC3 & MECC_SINGLE_ERR_ADDR_ECC3_SINGLE_ERR_ECC_MASK) >>
                          MECC_SINGLE_ERR_ADDR_ECC3_SINGLE_ERR_ECC_SHIFT);
            info->singleErrorAddress = (base->SINGLE_ERR_ADDR_ECC3 & MECC_SINGLE_ERR_ADDR_ECC3_SINGLE_ERR_ADDR_MASK) >>
                                       MECC_SINGLE_ERR_ADDR_ECC3_SINGLE_ERR_ADDR_SHIFT;
            info->singleErrorDataLow  = base->SINGLE_ERR_DATA_LOW3;
            info->singleErrorDataHigh = base->SINGLE_ERR_DATA_HIGH3;
            tempPosLow                = (uint8_t)base->SINGLE_ERR_POS_LOW3;
            tempPosHigh               = (uint8_t)base->SINGLE_ERR_POS_HIGH3;
            break;

        default:
            status = kStatus_MECC_BankMiss;
            break;
    }

    while (tempPosLow > 0U)
    {
        tempPosLow = tempPosLow >> 1;
        counter++;
    }

    if (counter == 0U)
    {
        info->singleErrorPosLow = 0;
    }
    else
    {
        info->singleErrorPosLow = counter - 1U;
    }

    counter = 0U;
    while (tempPosHigh > 0U)
    {
        tempPosHigh = tempPosHigh >> 1;
        counter++;
    }

    if (counter == 0U)
    {
        info->singleErrorPosHigh = 0;
    }
    else
    {
        info->singleErrorPosHigh = counter - 1U;
    }

    return status;
}
